@@ -27,12 +27,14 @@ class WhisperStatistics(Statistics):
                 "recall": {},
                 "precision": {},
                 "f1": {},
+                "reject_rate": {}
             },
             "trie": {
                 "accuracy": tuple(),
                 "recall": {},
                 "precision": {},
                 "f1": {},
+                "reject_rate": {}
             }
         }
 
@@ -57,6 +59,11 @@ class WhisperStatistics(Statistics):
                                                                           mode)
             self.indicator["trie"]["precision"][mode] = self.precision(self.df_trie, "type", "predict_type", mode)
 
+    def count_reject_rate(self, mode: str = "政治"):
+        self.indicator["no_trie"]["reject_rate"][mode] = self.reject_rate(self.df_no_trie, "type", "predict_label",
+                                                                          mode)
+        self.indicator["trie"]["reject_rate"][mode] = self.reject_rate(self.df_trie, "type", "predict_label", mode)
+
     def parse_standard_and_result(self, standard_file: str, result_file: str = None):
         standard_df = pd.read_csv(standard_file)
         lines = None
@@ -113,6 +120,8 @@ class WhisperStatistics(Statistics):
         for _type in ["整体", "政治"] + other_type:
             self.count_recall(_type)
             self.count_precision(_type)
+            if _type != "整体":
+                self.count_reject_rate(_type)
         self.__count_f1()
 
     def _get_result_type(self, words: list):
